Module: Google::Cloud::PolicyTroubleshooter::Iam
- Defined in:
- lib/google/cloud/policy_troubleshooter/iam.rb,
lib/google/cloud/policy_troubleshooter/iam/version.rb
Class Method Summary collapse
-
.configure {|::Google::Cloud.configure.policy_troubleshooter_iam| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-policy_troubleshooter-iam library.
-
.policy_troubleshooter(version: :v3, transport: :grpc, &block) ⇒ ::Object
Create a new client object for PolicyTroubleshooter.
-
.policy_troubleshooter_available?(version: :v3, transport: :grpc) ⇒ boolean
Determines whether the PolicyTroubleshooter service is supported by the current client.
Class Method Details
.configure {|::Google::Cloud.configure.policy_troubleshooter_iam| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-policy_troubleshooter-iam library.
The following configuration parameters are supported:
credentials(type:String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.lib_name(type:String) - The library name as recorded in instrumentation and logging.lib_version(type:String) - The library version as recorded in instrumentation and logging.interceptors(type:Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.timeout(type:Numeric) - Default timeout in seconds.metadata(type:Hash{Symbol=>String}) - Additional headers to be sent with the call.retry_policy(type:Hash) - The retry policy. The value is a hash with the following keys::initial_delay(type:Numeric) - The initial delay in seconds.:max_delay(type:Numeric) - The max delay in seconds.:multiplier(type:Numeric) - The incremental backoff multiplier.:retry_codes(type:Array<String>) - The error codes that should trigger a retry.
149 150 151 152 153 |
# File 'lib/google/cloud/policy_troubleshooter/iam.rb', line 149 def self.configure yield ::Google::Cloud.configure.policy_troubleshooter_iam if block_given? ::Google::Cloud.configure.policy_troubleshooter_iam end |
.policy_troubleshooter(version: :v3, transport: :grpc, &block) ⇒ ::Object
Create a new client object for PolicyTroubleshooter.
By default, this returns an instance of
Google::Cloud::PolicyTroubleshooter::Iam::V3::PolicyTroubleshooter::Client
for a gRPC client for version V3 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the PolicyTroubleshooter service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the PolicyTroubleshooter service. You can determine whether the method will succeed by calling policy_troubleshooter_available?.
About PolicyTroubleshooter
IAM Policy Troubleshooter service.
This service helps you troubleshoot access issues for Google Cloud resources.
78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/google/cloud/policy_troubleshooter/iam.rb', line 78 def self.policy_troubleshooter version: :v3, transport: :grpc, &block require "google/cloud/policy_troubleshooter/iam/#{version.to_s.downcase}" package_name = Google::Cloud::PolicyTroubleshooter::Iam .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::PolicyTroubleshooter::Iam.const_get(package_name).const_get(:PolicyTroubleshooter) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.policy_troubleshooter_available?(version: :v3, transport: :grpc) ⇒ boolean
Determines whether the PolicyTroubleshooter service is supported by the current client. If true, you can retrieve a client object by calling policy_troubleshooter. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the PolicyTroubleshooter service, or if the versioned client gem needs an update to support the PolicyTroubleshooter service.
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/google/cloud/policy_troubleshooter/iam.rb', line 102 def self.policy_troubleshooter_available? version: :v3, transport: :grpc require "google/cloud/policy_troubleshooter/iam/#{version.to_s.downcase}" package_name = Google::Cloud::PolicyTroubleshooter::Iam .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Cloud::PolicyTroubleshooter::Iam.const_get package_name return false unless service_module.const_defined? :PolicyTroubleshooter service_module = service_module.const_get :PolicyTroubleshooter if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |